path

Function path 

pub fn path<B: GraphBackend>(
    backend: &B,
    start: &str,
    goal: &str,
) -> Result<Option<Vec<String>>, B::Error>
Find a path from start to goal using BFS over edges.

Returns the list of node ids forming the path, or None if unreachable.

Errors

Returns an error if the backend fails.